Struct Formatter
Source pub struct Formatter<'a> {
pub very_start: Option<&'a str>,
pub very_end: Option<&'a str>,
pub start: Option<&'a str>,
pub end: Option<&'a str>,
pub middle: Option<&'a str>,
pub new_line_chars: Option<&'a str>,
}
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.